Index: Source/platform/heap/ThreadState.h |
diff --git a/Source/platform/heap/ThreadState.h b/Source/platform/heap/ThreadState.h |
index 3b2c8d649be43b4dc04a4e88083f4b4c0947efe3..c50caa516de3d0c73515aaad5c8992d486a56937 100644 |
--- a/Source/platform/heap/ThreadState.h |
+++ b/Source/platform/heap/ThreadState.h |
@@ -332,9 +332,9 @@ public: |
// - It is valid that the next GC is scheduled while some thread |
// has not yet completed its lazy sweeping of the last GC. |
// In this case, the next GC just cancels the remaining lazy sweeping. |
// Specifically, preGC() of the next GC calls makeConsistentForSweeping() |
// and it marks all not-yet-swept objets as dead. |
- void makeConsistentForSweeping(); |
+ void makeConsistentForGC(); |
void preGC(); |
void postGC(GCType); |
void preSweep(); |
@@ -332,9 +332,9 @@ public: |
// has not yet completed its lazy sweeping of the last GC. |
// In this case, the next GC just cancels the remaining lazy sweeping. |
- // Specifically, preGC() of the next GC calls makeConsistentForSweeping() |
+ // Specifically, preGC() of the next GC calls makeConsistentForGC() |
// and it marks all not-yet-swept objets as dead. |